@@ -13,6 +13,10 @@ import sentences.sentences_english as sent
 
 next_func = None
 
+def overlap(a, b):
+	result = [i for i in a  if i in b]
+	return bool(result)
+
 def parse_input(input):
 	input = input.lower()
 	if next_func:
@@ -121,6 +125,15 @@ def parse_to_nums(input):
 				nlist.append(i)
 	return nlist, has_nums
 				
+########### Callback functions ####################
+def should_read_email(input):
+	global next_func
+	next_func = None
+	if overlap(input.split(), sent.affirmative) and not overlap(input.split(), sent.negative):
+		return '', 'self.read_email()'
+	else:
+		return 'Okay.', None
+
 
 ########### Common questions/functions ############
 def ai(input):
